==> ejc-rmat-impl-3.0.0-20220921.070016-74-sources.jar: com/ejianc/business/rmat/service/IRentSettlementService.java <==
package com.ejianc.business.rmat.service;

import com.ejianc.business.finance.vo.ParamsCheckVO;
import com.ejianc.business.rmat.bean.RentSettlementEntity;
import com.ejianc.business.rmat.vo.RentSettlementDetailVO;
import com.ejianc.business.rmat.vo.RentSettlementRecordVO;
import com.ejianc.business.rmat.vo.RentSettlementVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;

import java.math.BigDecimal;
import java.util.List;

/**
 * <p>
 * 设备合同结算表 服务类
 * </p>
 *
 * @author yqls
 * @since 2020-06-10
 */
public interface IRentSettlementService extends IBaseService<RentSettlementEntity> {
    /**
     * 保存或修改信息
     *
     * @param RentSettlementVo
     * @return
     */
    CommonResponse<RentSettlementVO> saveOrUpdate(RentSettlementVO RentSettlementVo);

    /**
     * 根据主键ID查询详情
     *
     * @param id
     * @return
     */
    RentSettlementVO queryDetail(Long id);

    RentSettlementVO queryDetails(Long id);

    void pullCost(Long id);

    RentSettlementRecordVO querySettlementRecord(Long id);
    /**
     * 删除信息
     *
     * @param vos
     */
    void deleteRentSettlement(List<RentSettlementVO> vos);

    CommonResponse<RentSettlementVO> pushCost(RentSettlementVO rentSettlementVo);

    void costPush(RentSettlementEntity settlementEntity);

    ParamsCheckVO checkParams(BigDecimal sumPayMny, BigDecimal payMny, BigDecimal contractMny);

    Integer queryById(Long id,Long contractId);

    Integer queryByContractId(Long contractId);

    ParamsCheckVO checkParams(Integer purchaseType, BigDecimal settlementTaxMny, BigDecimal sumSettleMentTaxMny, BigDecimal contractTaxMny);
    
    List<RentSettlementDetailVO> settleExcelDownload(RentSettlementVO vo);

}

==> ejc-rmat-impl-3.0.0-20230316.030417-138-sources.jar: com/ejianc/business/rmat/service/IRentSettlementService.java <==
package com.ejianc.business.rmat.service;

import com.ejianc.business.rmat.bean.RentSettlementEntity;
import com.ejianc.business.rmat.vo.ParamsCheckVO;
import com.ejianc.business.rmat.vo.RentSettlementDetailVO;
import com.ejianc.business.rmat.vo.RentSettlementRecordVO;
import com.ejianc.business.rmat.vo.RentSettlementVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;

import java.math.BigDecimal;
import java.util.List;

/**
 * <p>
 * 设备合同结算表 服务类
 * </p>
 *
 * @author yqls
 * @since 2020-06-10
 */
public interface IRentSettlementService extends IBaseService<RentSettlementEntity> {
    /**
     * 保存或修改信息
     *
     * @param RentSettlementVo
     * @return
     */
    CommonResponse<RentSettlementVO> saveOrUpdate(RentSettlementVO RentSettlementVo);

    /**
     * 根据主键ID查询详情
     *
     * @param id
     * @return
     */
    RentSettlementVO queryDetail(Long id);

    RentSettlementVO queryDetails(Long id);

    void pullCost(Long id);

    RentSettlementRecordVO querySettlementRecord(Long id);
    /**
     * 删除信息
     *
     * @param vos
     */
    void deleteRentSettlement(List<RentSettlementVO> vos);

    CommonResponse<RentSettlementVO> pushCost(RentSettlementVO rentSettlementVo);

    void costPush(RentSettlementEntity settlementEntity);

    ParamsCheckVO checkParams(BigDecimal sumPayMny, BigDecimal payMny, BigDecimal contractMny);

    Integer queryById(Long id,Long contractId);

    Integer queryByContractId(Long contractId);

    ParamsCheckVO checkParams(Long id, Long contractId, Integer purchaseType, BigDecimal settlementTaxMny, BigDecimal contractTaxMny);
    
    List<RentSettlementDetailVO> settleExcelDownload(RentSettlementVO vo);

}
